@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 
 CConnectCommand::CConnectCommand(CServer const& server, ServerHandle const& handle, Credentials const& credentials, bool retry_connecting)
 	: server_(server)
@@ -94,8 +94,8 @@ std::wstring CRawCommand::GetCommand() const
 	return m_command;
 }
 
-CDeleteCommand::CDeleteCommand(const CServerPath& path, std::deque<std::wstring>&& files)
-	: m_path(path), m_files(files)
+CDeleteCommand::CDeleteCommand(const CServerPath& path, std::vector<std::wstring>&& files)
+	: m_path(path), files_(files)
 {
 }
 
