@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "directorylistingparser.h"
 #include "controlsocket.h"
 
