@@ -32,6 +32,10 @@
  * get concatenated to be parsed again (and discarded if not recognized).
  */
 
+#include "../include/directorylisting.h"
+#include "../include/server.h"
+
+#include <deque>
 #include <vector>
 
 class CLine;
