@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "controlsocket.h"
 #include "directorycache.h"
 #include "engineprivate.h"
@@ -11,6 +11,8 @@
 #include "storj/storjcontrolsocket.h"
 #endif
 
+#include "../include/engine_options.h"
+
 #include <libfilezilla/event_loop.hpp>
 
 #include <algorithm>
@@ -42,7 +44,7 @@ CFileZillaEnginePrivate::CFileZillaEnginePrivate(CFileZillaEngineContext& contex
 	, opLockManager_(context.GetOpLockManager())
 	, notification_handler_(notificationHandler)
 	, m_engine_id(get_next_engine_id())
-	, m_options(context.GetOptions())
+	, options_(context.GetOptions())
 	, rate_limiter_(context.GetRateLimiter())
 	, directory_cache_(context.GetDirectoryCache())
 	, path_cache_(context.GetPathCache())
@@ -64,17 +66,17 @@ CFileZillaEnginePrivate::CFileZillaEnginePrivate(CFileZillaEngineContext& contex
 		queue_logs_ = queue_logs;
 	}
 
-	RegisterOption(OPTION_LOGGING_SHOW_DETAILED_LOGS);
-	RegisterOption(OPTION_LOGGING_DEBUGLEVEL);
-	RegisterOption(OPTION_LOGGING_RAWLISTING);
+	options_.watch(OPTION_LOGGING_SHOW_DETAILED_LOGS, this);
+	options_.watch(OPTION_LOGGING_DEBUGLEVEL, this);
+	options_.watch(OPTION_LOGGING_RAWLISTING, this);
 }
 
 bool CFileZillaEnginePrivate::ShouldQueueLogsFromOptions() const
 {
 	return
-		m_options.GetOptionVal(OPTION_LOGGING_RAWLISTING) == 0 &&
-		m_options.GetOptionVal(OPTION_LOGGING_DEBUGLEVEL) == 0 &&
-		m_options.GetOptionVal(OPTION_LOGGING_SHOW_DETAILED_LOGS) == 0;
+		options_.get_int(OPTION_LOGGING_RAWLISTING) == 0 &&
+		options_.get_int(OPTION_LOGGING_DEBUGLEVEL) == 0 &&
+		options_.get_int(OPTION_LOGGING_SHOW_DETAILED_LOGS) == 0;
 }
 
 namespace {
@@ -97,8 +99,8 @@ void erase_unordered(C & container, V const& v) noexcept
 
 CFileZillaEnginePrivate::~CFileZillaEnginePrivate()
 {
+	options_.unwatch_all(this);
 	remove_handler();
-	UnregisterAllOptions();
 
 	m_maySendNotificationEvent = false;
 
@@ -141,9 +143,11 @@ bool CFileZillaEnginePrivate::IsConnected() const
 	return controlSocket_ != nullptr;
 }
 
-void CFileZillaEnginePrivate::AddNotification(fz::scoped_lock& lock, CNotification *pNotification)
+void CFileZillaEnginePrivate::AddNotification(fz::scoped_lock& lock, std::unique_ptr<CNotification> && notification)
 {
-	m_NotificationList.push_back(pNotification);
+	if (notification) {
+		m_NotificationList.push_back(notification.release());
+	}
 
 	if (m_maySendNotificationEvent) {
 		m_maySendNotificationEvent = false;
@@ -152,32 +156,32 @@ void CFileZillaEnginePrivate::AddNotification(fz::scoped_lock& lock, CNotificati
 	}
 }
 
-void CFileZillaEnginePrivate::AddNotification(CNotification *pNotification)
+void CFileZillaEnginePrivate::AddNotification(std::unique_ptr<CNotification> && notification)
 {
 	fz::scoped_lock lock(notification_mutex_);
-	AddNotification(lock, pNotification);
+	AddNotification(lock, std::move(notification));
 }
 
-void CFileZillaEnginePrivate::AddLogNotification(CLogmsgNotification *pNotification)
+void CFileZillaEnginePrivate::AddLogNotification(std::unique_ptr<CLogmsgNotification> && notification)
 {
 	fz::scoped_lock lock(notification_mutex_);
 
-	if (pNotification->msgType == logmsg::error) {
+	if (notification->msgType == logmsg::error) {
 		queue_logs_ = false;
 
 		m_NotificationList.insert(m_NotificationList.end(), queued_logs_.begin(), queued_logs_.end());
 		queued_logs_.clear();
-		AddNotification(lock, pNotification);
+		AddNotification(lock, std::move(notification));
 	}
-	else if (pNotification->msgType == logmsg::status) {
+	else if (notification->msgType == logmsg::status) {
 		ClearQueuedLogs(lock, false);
-		AddNotification(lock, pNotification);
+		AddNotification(lock, std::move(notification));
 	}
 	else if (!queue_logs_) {
-		AddNotification(lock, pNotification);
+		AddNotification(lock, std::move(notification));
 	}
 	else {
-		queued_logs_.push_back(pNotification);
+		queued_logs_.push_back(notification.release());
 	}
 }
 
@@ -230,6 +234,10 @@ int CFileZillaEnginePrivate::ResetOperation(int nErrorCode)
 		}
 
 		if (currentCommand_->GetId() == Command::connect) {
+			if (m_retryTimer) {
+				return FZ_REPLY_WOULDBLOCK;
+			}
+
 			if (!(nErrorCode & ~(FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED | FZ_REPLY_TIMEOUT | FZ_REPLY_CRITICALERROR | FZ_REPLY_PASSWORDFAILED)) &&
 				nErrorCode & (FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED))
 			{
@@ -239,7 +247,7 @@ int CFileZillaEnginePrivate::ResetOperation(int nErrorCode)
 
 				if ((nErrorCode & FZ_REPLY_CRITICALERROR) != FZ_REPLY_CRITICALERROR) {
 					++m_retryCount;
-					if (m_retryCount < m_options.GetOptionVal(OPTION_RECONNECTCOUNT) && connectCommand.RetryConnecting()) {
+					if (m_retryCount < options_.get_int(OPTION_RECONNECTCOUNT) && connectCommand.RetryConnecting()) {
 						fz::duration delay = GetRemainingReconnectDelay(connectCommand.GetServer());
 						if (!delay) {
 							delay = fz::duration::from_seconds(1);
@@ -253,10 +261,7 @@ int CFileZillaEnginePrivate::ResetOperation(int nErrorCode)
 			}
 		}
 
-		COperationNotification *notification = new COperationNotification();
-		notification->nReplyCode = nErrorCode;
-		notification->commandId = currentCommand_->GetId();
-		AddNotification(notification);
+		AddNotification(std::make_unique<COperationNotification>(nErrorCode, currentCommand_->GetId()));
 
 		currentCommand_.reset();
 	}
@@ -340,26 +345,23 @@ int CFileZillaEnginePrivate::List(CListCommand const& command)
 				}
 			}
 			if (!path.empty()) {
-				CDirectoryListing *pListing = new CDirectoryListing;
+				CDirectoryListing listing;
 				bool is_outdated = false;
-				bool found = directory_cache_.Lookup(*pListing, server, path, true, is_outdated);
+				bool found = directory_cache_.Lookup(listing, server, path, true, is_outdated);
 				if (found && !is_outdated) {
-					if (pListing->get_unsure_flags()) {
+					if (listing.get_unsure_flags()) {
 						flags |= LIST_FLAG_REFRESH;
 					}
 					else {
 						if (!avoid) {
-							CDirectoryListingNotification *pNotification = new CDirectoryListingNotification(pListing->path, true);
-							AddNotification(pNotification);
+							AddNotification(std::make_unique<CDirectoryListingNotification>(listing.path, true));
 						}
-						delete pListing;
 						return FZ_REPLY_OK;
 					}
 				}
 				if (is_outdated) {
 					flags |= LIST_FLAG_REFRESH;
 				}
-				delete pListing;
 			}
 		}
 	}
@@ -426,7 +428,7 @@ void CFileZillaEnginePrivate::RegisterFailedLoginAttempt(const CServer& server,
 	std::list<t_failedLogins>::iterator iter = m_failedLogins.begin();
 	while (iter != m_failedLogins.end()) {
 		fz::duration const span = fz::monotonic_clock::now() - iter->time;
-		if (span.get_seconds() >= m_options.GetOptionVal(OPTION_RECONNECTDELAY) ||
+		if (span.get_seconds() >= options_.get_int(OPTION_RECONNECTDELAY) ||
 			iter->server.SameResource(server) || (!critical && (iter->server.GetHost() == server.GetHost() && iter->server.GetPort() == server.GetPort())))
 		{
 			std::list<t_failedLogins>::iterator prev = iter;
@@ -451,7 +453,7 @@ fz::duration CFileZillaEnginePrivate::GetRemainingReconnectDelay(CServer const&
 	std::list<t_failedLogins>::iterator iter = m_failedLogins.begin();
 	while (iter != m_failedLogins.end()) {
 		fz::duration const span = fz::monotonic_clock::now() - iter->time;
-		fz::duration const delay = fz::duration::from_seconds(m_options.GetOptionVal(OPTION_RECONNECTDELAY));
+		fz::duration const delay = fz::duration::from_seconds(options_.get_int(OPTION_RECONNECTDELAY));
 		if (span >= delay) {
 			std::list<t_failedLogins>::iterator prev = iter;
 			++iter;
@@ -476,14 +478,15 @@ void CFileZillaEnginePrivate::OnTimer(fz::timer_id)
 	if (!m_retryTimer) {
 		return;
 	}
-	m_retryTimer = 0;
 
 	if (!currentCommand_ || currentCommand_->GetId() != Command::connect) {
+		m_retryTimer = 0;
 		logger_->log(logmsg::debug_warning, L"CFileZillaEnginePrivate::OnTimer called without pending Command::connect");
 		return;
 	}
 
 	controlSocket_.reset();
+	m_retryTimer = 0;
 
 	int res = ContinueConnect();
 	if (res == FZ_REPLY_CONTINUE) {
@@ -572,7 +575,7 @@ void CFileZillaEnginePrivate::InvalidateCurrentWorkingDirs(const CServerPath& pa
 			continue;
 		}
 
-		engine->send_event(new CInvalidateCurrentWorkingDirEvent(ownServer, path));
+		engine->send_event<CInvalidateCurrentWorkingDirEvent>(ownServer, path);
 	}
 }
 
@@ -580,12 +583,13 @@ void CFileZillaEnginePrivate::operator()(fz::event_base const& ev)
 {
 	fz::scoped_lock lock(mutex_);
 
-	fz::dispatch<CFileZillaEngineEvent, CCommandEvent, CAsyncRequestReplyEvent, fz::timer_event, CInvalidateCurrentWorkingDirEvent>(ev, this,
+	fz::dispatch<CFileZillaEngineEvent, CCommandEvent, CAsyncRequestReplyEvent, fz::timer_event, CInvalidateCurrentWorkingDirEvent, options_changed_event>(ev, this,
 		&CFileZillaEnginePrivate::OnEngineEvent,
 		&CFileZillaEnginePrivate::OnCommandEvent,
 		&CFileZillaEnginePrivate::OnSetAsyncRequestReplyEvent,
 		&CFileZillaEnginePrivate::OnTimer,
-		&CFileZillaEnginePrivate::OnInvalidateCurrentWorkingDir
+		&CFileZillaEnginePrivate::OnInvalidateCurrentWorkingDir,
+		&CFileZillaEnginePrivate::OnOptionsChanged
 		);
 }
 
@@ -695,10 +699,7 @@ void CFileZillaEnginePrivate::DoCancel()
 		m_retryTimer = 0;
 
 		logger_->log(logmsg::error, _("Connection attempt interrupted by user"));
-		COperationNotification *notification = new COperationNotification();
-		notification->nReplyCode = FZ_REPLY_DISCONNECTED | FZ_REPLY_CANCELED;
-		notification->commandId = Command::connect;
-		AddNotification(notification);
+		AddNotification(std::make_unique<COperationNotification>(FZ_REPLY_DISCONNECTED | FZ_REPLY_CANCELED, Command::connect));
 
 		ClearQueuedLogs(true);
 	}
@@ -798,7 +799,7 @@ void CFileZillaEnginePrivate::SetActive(int direction)
 {
 	int const old_status = m_activeStatus[direction].fetch_or(0x1);
 	if (!old_status) {
-		AddNotification(new CActiveNotification(direction));
+		AddNotification(std::make_unique<CActiveNotification>(direction));
 	}
 }
 
@@ -849,7 +850,7 @@ int CFileZillaEnginePrivate::Cancel()
 	return FZ_REPLY_WOULDBLOCK;
 }
 
-void CFileZillaEnginePrivate::OnOptionsChanged(changed_options_t const&)
+void CFileZillaEnginePrivate::OnOptionsChanged(watched_options const&)
 {
 	bool queue_logs = ShouldQueueLogsFromOptions();
 	if (queue_logs) {
@@ -880,7 +881,7 @@ void CTransferStatusManager::Reset()
 		send_state_ = 0;
 	}
 
-	engine_.AddNotification(new CTransferStatusNotification());
+	engine_.AddNotification(std::make_unique<CTransferStatusNotification>());
 }
 
 void CTransferStatusManager::Init(int64_t totalSize, int64_t startOffset, bool list)
@@ -916,7 +917,7 @@ void CTransferStatusManager::SetMadeProgress()
 
 void CTransferStatusManager::Update(int64_t transferredBytes)
 {
-	CNotification* notification = nullptr;
+	std::unique_ptr<CNotification> notification;
 
 	{
 		int64_t oldOffset = currentOffset_.fetch_add(transferredBytes);
@@ -928,14 +929,14 @@ void CTransferStatusManager::Update(int64_t transferredBytes)
 
 			if (!send_state_) {
 				status_.currentOffset += currentOffset_.exchange(0);
-				notification = new CTransferStatusNotification(status_);
+				notification = std::make_unique<CTransferStatusNotification>(status_);
 			}
 			send_state_ = 2;
 		}
 	}
 
 	if (notification) {
-		engine_.AddNotification(notification);
+		engine_.AddNotification(std::move(notification));
 	}
 }
 
