@@ -1,12 +1,12 @@
-#include <filezilla.h>
-#include "tlssocket.h"
+#include "filezilla.h"
 
 #include <libfilezilla/format.hpp>
 #include <libfilezilla/time.hpp>
+#include <libfilezilla/tls_layer.hpp>
 
-#include <random>
 #include <cstdint>
 #include <cwctype>
+#include <random>
 
 #include <string.h>
 
@@ -14,7 +14,7 @@ std::wstring GetDependencyVersion(lib_dependency d)
 {
 	switch (d) {
 	case lib_dependency::gnutls:
-		return CTlsSocket::GetGnutlsVersion();
+		return fz::to_wstring(fz::tls_layer::get_gnutls_version());
 	default:
 		return std::wstring();
 	}
@@ -32,7 +32,7 @@ std::wstring GetDependencyName(lib_dependency d)
 
 std::string ListTlsCiphers(std::string const& priority)
 {
-	return CTlsSocket::ListTlsCiphers(priority);
+	return fz::tls_layer::list_tls_ciphers(priority);
 }
 
 #if FZ_WINDOWS
@@ -59,31 +59,23 @@ int GetSystemErrorCode()
 }
 
 namespace {
-inline std::string ProcessStrerrorResult(int ret, char* buf, int err)
+template<typename Arg>
+inline std::string ProcessStrerrorResult(Arg ret, char* buf, int err)
 {
-	// For XSI strerror_r
-	std::string s;
-	if (!ret) {
-		buf[999] = 0;
-		s = buf;
+	if constexpr (std::is_same_v<Arg, int>) {
+		// XSI strerror_r
+		if (!ret) {
+			buf[999] = 0;
+			return buf;
+		}
 	}
 	else {
-		s = fz::to_string(fz::sprintf(_("Unknown error %d"), err));
+		// GNU strerror_r
+		if (ret && *ret) {
+			return ret;
+		}
 	}
-	return s;
-}
-
-inline std::string ProcessStrerrorResult(char* ret, char*, int err)
-{
-	// For GNU strerror_r
-	std::string s;
-	if (ret) {
-		s = ret;
-	}
-	else {
-		s = fz::to_string(fz::sprintf(_("Unknown error %d"), err));
-	}
-	return s;
+	return fz::to_string(fz::sprintf(_("Unknown error %d"), err));
 }
 }
 
@@ -97,43 +89,10 @@ std::string GetSystemErrorDescription(int err)
 
 namespace fz {
 
-namespace {
-std::wstring default_translator(char const* const t)
-{
-	return fz::to_wstring(t);
-}
-
-std::wstring default_translator_pf(char const* const singular, char const* const plural, int64_t n)
-{
-	return fz::to_wstring((n == 1) ? singular : plural);
-}
-
-std::wstring(*translator)(char const* const) = default_translator;
-std::wstring(*translator_pf)(char const* const singular, char const* const plural, int64_t n) = default_translator_pf;
-}
-
-void set_translators(
-	std::wstring(*s)(char const* const t),
-	std::wstring(*pf)(char const* const singular, char const* const plural, int64_t n)
-)
-{
-	translator = s ? s : default_translator;
-	translator_pf = pf ? pf : default_translator_pf;
-}
-
-std::wstring translate(char const * const t)
-{
-	return translator(t);
-}
-
-std::wstring translate(char const * const singular, char const * const plural, int64_t n)
-{
-	return translator_pf(singular, plural, n);
-}
-
 std::wstring str_tolower(std::wstring const& source)
 {
 	std::wstring ret;
+	ret.reserve(source.size());
 	for (auto const& c : source) {
 		ret.push_back(std::towlower(c));
 	}
