@@ -17,27 +17,28 @@ struct t_protocolInfo
 };
 
 static const t_protocolInfo protocolInfos[] = {
-	{ FTP,             L"ftp",      false, 21, true,  fztranslate_mark("FTP - File Transfer Protocol with optional encryption"), L"" },
-	{ SFTP,            L"sftp",     true,  22, false, "SFTP - SSH File Transfer Protocol",                                       L"" },
-	{ HTTP,            L"http",     true,  80, false, "HTTP - Hypertext Transfer Protocol",                                      L"" },
-	{ HTTPS,           L"https",    true, 443, true,  fztranslate_mark("HTTPS - HTTP over TLS"),                                 L"" },
-	{ FTPS,            L"ftps",     true, 990, true,  fztranslate_mark("FTPS - FTP over implicit TLS"),                          L"" },
-	{ FTPES,           L"ftpes",    true,  21, true,  fztranslate_mark("FTPES - FTP over explicit TLS"),                         L"" },
-	{ INSECURE_FTP,    L"ftp",      false, 21, true,  fztranslate_mark("FTP - Insecure File Transfer Protocol"),                 L"" },
-	{ S3,              L"s3",       true, 443, false, "S3 - Amazon Simple Storage Service",                                      L"" },
-	{ STORJ,           L"storj",    true, 443, true,  fztranslate_mark("Storj - Decentralized Cloud Storage"),                   L"" },
-	{ WEBDAV,          L"webdav",   true, 443, true,  fztranslate_mark("WebDAV using HTTPS"),                                    L"https" },
-	{ AZURE_FILE,      L"azfile",   true, 443, false, "Microsoft Azure File Storage Service",                                    L"https" },
-	{ AZURE_BLOB,      L"azblob",   true, 443, false, "Microsoft Azure Blob Storage Service",                                    L"https" },
-	{ SWIFT,           L"swift",    true, 443, false, "OpenStack Swift",                                                         L"https" },
-	{ GOOGLE_CLOUD,    L"google",   true, 443, false, "Google Cloud Storage",                                                    L"https" },
-	{ GOOGLE_DRIVE,    L"gdrive",   true, 443, false, "Google Drive",                                                            L"https" },
-	{ DROPBOX,         L"dropbox",  true, 443, false, "Dropbox",                                                                 L"https" },
-	{ ONEDRIVE,        L"onedrive", true, 443, false, "Microsoft OneDrive",                                                      L"https" },
-	{ B2,              L"b2",       true, 443, false, "Backblaze B2",                                                            L"https" },
-	{ BOX,             L"box",      true, 443, false, "Box",                                                                     L"https" },
-	{ INSECURE_WEBDAV, L"webdav",   true,  80, true,  fztranslate_mark("WebDAV using HTTP (insecure)"),                          L"http" },
-	{ UNKNOWN,         L"",         false, 21, false, "",                                                                        L"" }
+	{ FTP,             L"ftp",       false, 21,  true,  fztranslate_mark("FTP - File Transfer Protocol with optional encryption"), L"" },
+	{ SFTP,            L"sftp",      true,  22,  false, "SFTP - SSH File Transfer Protocol",                                       L"" },
+	{ HTTP,            L"http",      true,  80,  false, "HTTP - Hypertext Transfer Protocol",                                      L"" },
+	{ HTTPS,           L"https",     true, 443,  true,  fztranslate_mark("HTTPS - HTTP over TLS"),                                 L"" },
+	{ FTPS,            L"ftps",      true, 990,  true,  fztranslate_mark("FTPS - FTP over implicit TLS"),                          L"" },
+	{ FTPES,           L"ftpes",     true,  21,  true,  fztranslate_mark("FTPES - FTP over explicit TLS"),                         L"" },
+	{ INSECURE_FTP,    L"ftp",       false, 21,  true,  fztranslate_mark("FTP - Insecure File Transfer Protocol"),                 L"" },
+	{ S3,              L"s3",        true, 443,  false, "S3 - Amazon Simple Storage Service",                                      L"" },
+	{ STORJ,           L"storj",     true, 7777, true,  fztranslate_mark("Tardigrade - Decentralized Cloud Storage"),              L"" },
+	{ WEBDAV,          L"webdav",    true, 443,  true,  fztranslate_mark("WebDAV using HTTPS"),                                    L"https" },
+	{ AZURE_FILE,      L"azfile",    true, 443,  false, "Microsoft Azure File Storage Service",                                    L"https" },
+	{ AZURE_BLOB,      L"azblob",    true, 443,  false, "Microsoft Azure Blob Storage Service",                                    L"https" },
+	{ SWIFT,           L"swift",     true, 443,  false, "OpenStack Swift",                                                         L"https" },
+	{ GOOGLE_CLOUD,    L"google",    true, 443,  false, "Google Cloud Storage",                                                    L"https" },
+	{ GOOGLE_DRIVE,    L"gdrive",    true, 443,  false, "Google Drive",                                                            L"https" },
+	{ DROPBOX,         L"dropbox",   true, 443,  false, "Dropbox",                                                                 L"https" },
+	{ ONEDRIVE,        L"onedrive",  true, 443,  false, "Microsoft OneDrive",                                                      L"https" },
+	{ B2,              L"b2",        true, 443,  false, "Backblaze B2",                                                            L"https" },
+	{ BOX,             L"box",       true, 443,  false, "Box",                                                                     L"https" },
+	{ INSECURE_WEBDAV, L"webdav",    true,  80,  true,  fztranslate_mark("WebDAV using HTTP (insecure)"),                          L"http" },
+	{ RACKSPACE,       L"rackspace", true, 443,  false, "Rackspace Cloud Storage",                                                 L"https" },
+	{ UNKNOWN,         L"",          false, 21,  false, "",                                                                        L"" }
 };
 
 static std::vector<ServerProtocol> const defaultProtocols = {
@@ -355,15 +356,20 @@ std::wstring CServer::Format(ServerFormat formatType, Credentials const& credent
 		return server;
 	}
 
-	if (m_port != GetDefaultPort(m_protocol)) {
+	if (m_port != GetDefaultPort(m_protocol) || formatType == ServerFormat::with_port) {
 		server += fz::sprintf(L":%d", m_port);
 	}
 
-	if (formatType == ServerFormat::with_optional_port) {
+	if (formatType == ServerFormat::with_optional_port || formatType == ServerFormat::with_port) {
 		return server;
 	}
 
 	auto user = GetUser();
+	if (m_protocol == STORJ) {
+		// FIXME: The API key is not a user name. Move it into credentials section in a future version.
+		// Hide it here, we shouldn't display the key like this.
+		user.clear();
+	}
 	if (credentials.logonType_ != LogonType::anonymous) {
 		// For now, only escape if formatting for URL.
 		// Open question: Do we need some form of escapement for presentation within the GUI,
@@ -561,7 +567,7 @@ bool CServer::ProtocolHasFeature(ServerProtocol const protocol, ProtocolFeature
 		break;
 	case ProtocolFeature::Charset:
 		if (protocol == FTP || protocol == FTPS || protocol == FTPES || protocol == INSECURE_FTP ||
-			protocol == STORJ || protocol == SFTP) {
+			protocol == SFTP) {
 			return true;
 		}
 		break;
@@ -894,6 +900,15 @@ std::vector<ParameterTraits> const& ExtraServerParameterTraits(ServerProtocol pr
 		}();
 		return ret;
 	}
+	case STORJ:
+	{
+		static std::vector<ParameterTraits> ret = []() {
+			std::vector<ParameterTraits> ret;
+			ret.emplace_back(ParameterTraits{"passphrase_hash", ParameterSection::custom, ParameterTraits::optional, std::wstring(), std::wstring()});
+			return ret;
+		}();
+		return ret;
+	}
 	default:
 		break;
 	}
