@@ -7,7 +7,7 @@ class CStorjFileTransferOpData final : public CFileTransferOpData, public CStorj
 {
 public:
 	CStorjFileTransferOpData(CStorjControlSocket & controlSocket, bool is_download, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path, CFileTransferCommand::t_transferSettings const& settings)
-		: CFileTransferOpData(is_download, local_file, remote_file, remote_path, settings)
+		: CFileTransferOpData(L"CStorjFileTransferOpData", is_download, local_file, remote_file, remote_path, settings)
 		, CStorjOpData(controlSocket)
 	{
 	}
@@ -15,10 +15,6 @@ public:
 	virtual int Send() override;
 	virtual int ParseResponse() override;
 	virtual int SubcommandResult(int prevResult, COpData const& previousOperation) override;
-
-private:
-	std::wstring bucket_;
-	std::wstring fileId_;
 };
 
 #endif
