@@ -2,8 +2,7 @@
 #define FILEZILLA_ENGINE_ENGINE_HEADER
 
 #include "commands.h"
-
-#include <notification.h>
+#include "notification.h"
 
 class CAsyncRequestNotification;
 class CFileZillaEngineContext;
@@ -62,7 +61,7 @@ public:
 	int CacheLookup(CServerPath const& path, CDirectoryListing& listing);
 
 private:
-	CFileZillaEnginePrivate* const impl_;
+	std::unique_ptr<CFileZillaEnginePrivate> impl_;
 };
 
 #endif
