@@ -43,7 +43,9 @@ enum ServerProtocol
 
 	INSECURE_WEBDAV,
 
-	MAX_VALUE = INSECURE_WEBDAV
+	RACKSPACE,
+
+	MAX_VALUE = RACKSPACE
 };
 
 enum ServerType
@@ -74,6 +76,7 @@ enum class ServerFormat
 {
 	host_only,
 	with_optional_port,
+	with_port,
 	with_user_and_optional_port,
 	url,
 	url_with_password
