@@ -2,8 +2,8 @@
 #define FILEZILLA_INTERFACE_MAINFRM_HEADER
 
 #include "statusbar.h"
-#include "engine_context.h"
-#include "notification.h"
+#include "../include/engine_context.h"
+#include "../include/notification.h"
 #include "serverdata.h"
 
 #include <wx/timer.h>
@@ -16,6 +16,8 @@
 #include "updater.h"
 #endif
 
+#include <list>
+
 class CAsyncRequestQueue;
 class CContextControl;
 class CLed;
@@ -28,11 +30,10 @@ class Site;
 class CSplitterWindowEx;
 class CStatusView;
 class CState;
-class CThemeProvider;
 class CToolBar;
 class CWindowStateManager;
 
-class CMainFrame final : public wxNavigationEnabled<wxFrame>, private COptionChangeEventHandler, public EngineNotificationHandler
+class CMainFrame final : public wxNavigationEnabled<wxFrame>, public COptionChangeEventHandler, public EngineNotificationHandler
 #if FZ_MANUALUPDATECHECK
 	, protected CUpdateHandler
 #endif
@@ -74,9 +75,9 @@ private:
 
 	bool CloseDialogsAndQuit(wxCloseEvent &event);
 	bool CreateMenus();
-	bool CreateQuickconnectBar();
+	void CreateQuickconnectBar();
 	bool CreateMainToolBar();
-	void OpenSiteManager(ServerWithCredentials const* pServer = 0);
+	void OpenSiteManager(Site const* site = 0);
 
 	void FocusNextEnabled(std::list<wxWindow*>& windowOrder, std::list<wxWindow*>::iterator iter, bool skipFirst, bool forward);
 
@@ -95,7 +96,6 @@ private:
 	CStatusView* m_pStatusView{};
 	CQueueView* m_pQueueView{};
 	CLed* m_pActivityLed[2];
-	CThemeProvider* m_pThemeProvider{};
 #if FZ_MANUALUPDATECHECK
 	CUpdater* m_pUpdater{};
 	virtual void UpdaterStateChanged( UpdaterState s, build const& v );
@@ -115,7 +115,7 @@ private:
 
 	void SetupKeyboardAccelerators();
 
-	void OnOptionsChanged(changed_options_t const& options);
+	void OnOptionsChanged(watched_options const& options);
 
 	virtual void OnEngineEvent(CFileZillaEngine* engine); // Before thread jump
 	void DoOnEngineEvent(CFileZillaEngine* engine); // After thread jump
