@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "queue.h"
 #include "Mainfrm.h"
 #include "Options.h"
@@ -208,9 +208,10 @@ EVT_LIST_COL_CLICK(wxID_ANY, CQueueView::OnColumnClicked)
 END_EVENT_TABLE()
 
 CQueueView::CQueueView(CQueue* parent, int index, CMainFrame* pMainFrame, CAsyncRequestQueue *pAsyncRequestQueue)
-	: CQueueViewBase(parent, index, _("Queued files")),
-	m_pMainFrame(pMainFrame),
-	m_pAsyncRequestQueue(pAsyncRequestQueue)
+	: CQueueViewBase(parent, index, _("Queued files"))
+	, COptionChangeEventHandler(this)
+	, m_pMainFrame(pMainFrame)
+	, m_pAsyncRequestQueue(pAsyncRequestQueue)
 {
 	wxGetApp().AddStartupProfileRecord("CQueueView::CQueueView");
 
@@ -218,7 +219,7 @@ CQueueView::CQueueView(CQueue* parent, int index, CMainFrame* pMainFrame, CAsync
 		m_pAsyncRequestQueue->SetQueue(this);
 	}
 
-	int action = COptions::Get()->GetOptionVal(OPTION_QUEUE_COMPLETION_ACTION);
+	int action = COptions::Get()->get_int(OPTION_QUEUE_COMPLETION_ACTION);
 	if (action < 0 || action >= ActionAfterState::Count) {
 		action = 1;
 	}
@@ -230,9 +231,9 @@ CQueueView::CQueueView(CQueue* parent, int index, CMainFrame* pMainFrame, CAsync
 	std::vector<ColumnId> extraCols({colTransferStatus});
 	CreateColumns(extraCols);
 
-	RegisterOption(OPTION_NUMTRANSFERS);
-	RegisterOption(OPTION_CONCURRENTDOWNLOADLIMIT);
-	RegisterOption(OPTION_CONCURRENTUPLOADLIMIT);
+	COptions::Get()->watch(OPTION_NUMTRANSFERS, this);
+	COptions::Get()->watch(OPTION_CONCURRENTDOWNLOADLIMIT, this);
+	COptions::Get()->watch(OPTION_CONCURRENTUPLOADLIMIT, this);
 
 	CContextManager::Get()->RegisterHandler(this, STATECHANGE_REWRITE_CREDENTIALS, false);
 	CContextManager::Get()->RegisterHandler(this, STATECHANGE_QUITNOW, false);
@@ -249,6 +250,7 @@ CQueueView::CQueueView(CQueue* parent, int index, CMainFrame* pMainFrame, CAsync
 
 CQueueView::~CQueueView()
 {
+	COptions::Get()->unwatch_all(this);
 	DeleteEngines();
 
 	m_resize_timer.Stop();
@@ -339,7 +341,7 @@ bool CQueueView::QueueFiles(const bool queueOnly, const CLocalPath& localPath, c
 		}
 
 		std::wstring localFile = ReplaceInvalidCharacters(fileInfo.name);
-		if (dataObject.GetServerPath().GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION)) {
+		if (dataObject.GetServerPath().GetType() == VMS && COptions::Get()->get_int(OPTION_STRIP_VMS_REVISION)) {
 			localFile = StripVMSRevision(localFile);
 		}
 
@@ -426,7 +428,7 @@ void CQueueView::ProcessNotification(t_EngineData* pEngineData, std::unique_ptr<
 	{
 	case nId_logmsg:
 		m_pMainFrame->GetStatusView()->AddToLog(std::move(static_cast<CLogmsgNotification&>(*pNotification.get())));
-		if (COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION) == 2) {
+		if (COptions::Get()->get_int(OPTION_MESSAGELOG_POSITION) == 2) {
 			m_pQueue->Highlight(3);
 		}
 		break;
@@ -592,13 +594,13 @@ bool CQueueView::TryStartNextTransfer()
 	}
 
 	// Check transfer limit
-	if (m_activeCount >= COptions::Get()->GetOptionVal(OPTION_NUMTRANSFERS)) {
+	if (m_activeCount >= COptions::Get()->get_int(OPTION_NUMTRANSFERS)) {
 		return false;
 	}
 
 	// Check limits for concurrent up/downloads
-	const int maxDownloads = COptions::Get()->GetOptionVal(OPTION_CONCURRENTDOWNLOADLIMIT);
-	const int maxUploads = COptions::Get()->GetOptionVal(OPTION_CONCURRENTUPLOADLIMIT);
+	const int maxDownloads = COptions::Get()->get_int(OPTION_CONCURRENTDOWNLOADLIMIT);
+	const int maxUploads = COptions::Get()->get_int(OPTION_CONCURRENTUPLOADLIMIT);
 	TransferDirection wantedDirection;
 	if (maxDownloads && m_activeCountDown >= maxDownloads) {
 		if (maxUploads && m_activeCountUp >= maxUploads) {
@@ -762,13 +764,13 @@ bool CQueueView::TryStartNextTransfer()
 
 void CQueueView::ProcessReply(t_EngineData* pEngineData, COperationNotification const& notification)
 {
-	wxASSERT(notification.commandId != ::Command::none);
+	wxASSERT(notification.commandId_ != ::Command::none);
 
 	// Cancel pending requests
 	m_pAsyncRequestQueue->ClearPending(pEngineData->pEngine);
 
 	// Process reply from the engine
-	int replyCode = notification.nReplyCode;
+	int replyCode = notification.replyCode_;
 
 	if ((replyCode & FZ_REPLY_CANCELED) == FZ_REPLY_CANCELED) {
 		ResetReason reason;
@@ -1397,7 +1399,7 @@ bool CQueueView::Quit()
 		m_quit = 2;
 	}
 
-	SaveColumnSettings(OPTION_QUEUE_COLUMN_WIDTHS, -1, -1);
+	SaveColumnSettings(OPTION_QUEUE_COLUMN_WIDTHS, OPTIONS_NUM, OPTIONS_NUM);
 
 	m_resize_timer.Stop();
 
@@ -1452,7 +1454,7 @@ void CQueueView::CheckQueueState()
 bool CQueueView::IncreaseErrorCount(t_EngineData& engineData)
 {
 	++engineData.pItem->m_errorCount;
-	if (engineData.pItem->m_errorCount <= COptions::Get()->GetOptionVal(OPTION_RECONNECTCOUNT)) {
+	if (engineData.pItem->m_errorCount <= COptions::Get()->get_int(OPTION_RECONNECTCOUNT)) {
 		return true;
 	}
 
@@ -1527,7 +1529,7 @@ void CQueueView::DisplayQueueSize()
 void CQueueView::SaveQueue(bool silent)
 {
 	// Kiosk mode 2 doesn't save queue
-	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2) {
+	if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) == 2) {
 		return;
 	}
 
@@ -1562,7 +1564,7 @@ void CQueueView::LoadQueueFromXML()
 
 	document.remove_child(queue);
 
-	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2) {
+	if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) == 2) {
 		return;
 	}
 
@@ -1617,7 +1619,7 @@ void CQueueView::LoadQueue()
 		}
 
 		if (error || first_id > 0) {
-			if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 2) {
+			if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 2) {
 				if (!m_queue_storage.Clear()) {
 					error = true;
 				}
@@ -1887,7 +1889,7 @@ void CQueueView::OnActionAfter(wxCommandEvent& event)
 	}
 	else if (event.GetId() == XRCID("ID_ACTIONAFTER_RUNCOMMAND")) {
 		wxTextEntryDialog dlg(m_pMainFrame, _("Please enter the complete path of a program and its arguments. This command will be executed when the queue has finished processing.\nE.g. c:\\somePath\\file.exe under MS Windows or /somePath/file under Unix.\nYou need to properly quote commands and their arguments if they contain spaces."), _("Enter command"));
-		dlg.SetValue(COptions::Get()->GetOption(OPTION_QUEUE_COMPLETION_COMMAND));
+		dlg.SetValue(COptions::Get()->get_string(OPTION_QUEUE_COMPLETION_COMMAND));
 
 		if (dlg.ShowModal() == wxID_OK) {
 			const wxString &command = dlg.GetValue();
@@ -1896,7 +1898,7 @@ void CQueueView::OnActionAfter(wxCommandEvent& event)
 			}
 			else {
 				m_actionAfterState = ActionAfterState::RunCommand;
-				COptions::Get()->SetOption(OPTION_QUEUE_COMPLETION_COMMAND, command.ToStdWstring());
+				COptions::Get()->set(OPTION_QUEUE_COMPLETION_COMMAND, command.ToStdWstring());
 			}
 		}
 	}
@@ -1910,7 +1912,7 @@ void CQueueView::OnActionAfter(wxCommandEvent& event)
 #endif
 
 	if (m_actionAfterState != ActionAfterState::Reboot && m_actionAfterState != ActionAfterState::Shutdown && m_actionAfterState != ActionAfterState::Sleep && m_actionAfterState != ActionAfterState::CloseOnce) {
-		COptions::Get()->SetOption(OPTION_QUEUE_COMPLETION_ACTION, m_actionAfterState);
+		COptions::Get()->set(OPTION_QUEUE_COMPLETION_ACTION, m_actionAfterState);
 	}
 }
 
@@ -2118,12 +2120,11 @@ void CQueueView::SetDefaultFileExistsAction(CFileExistsNotification::OverwriteAc
 
 void CQueueView::OnSetDefaultFileExistsAction(wxCommandEvent &)
 {
-	if (!HasSelection())
+	if (!HasSelection()) {
 		return;
+	}
 
 	CDefaultFileExistsDlg dlg;
-	if (!dlg.Load(this, true))
-		return;
 
 	// Get current default action for the item
 	CFileExistsNotification::OverwriteAction downloadAction = CFileExistsNotification::unknown;
@@ -2134,35 +2135,38 @@ void CQueueView::OnSetDefaultFileExistsAction(wxCommandEvent &)
 	bool upload_unknown = false;
 
 	long item = -1;
-	for (;;)
-	{
+	for (;;) {
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-		if (item == -1)
+		if (item == -1) {
 			break;
+		}
 
 		CQueueItem* pItem = GetQueueItem(item);
-		if (!pItem)
+		if (!pItem) {
 			continue;
+		}
 
 		switch (pItem->GetType())
 		{
 		case QueueItemType::File:
 			{
 				CFileItem *pFileItem = (CFileItem*)pItem;
-				if (pFileItem->Download())
-				{
-					if (downloadAction == CFileExistsNotification::unknown)
+				if (pFileItem->Download()) {
+					if (downloadAction == CFileExistsNotification::unknown) {
 						downloadAction = pFileItem->m_defaultFileExistsAction;
-					else if (pFileItem->m_defaultFileExistsAction != downloadAction)
+					}
+					else if (pFileItem->m_defaultFileExistsAction != downloadAction) {
 						download_unknown = true;
+					}
 					has_download = true;
 				}
-				else
-				{
-					if (uploadAction == CFileExistsNotification::unknown)
+				else {
+					if (uploadAction == CFileExistsNotification::unknown) {
 						uploadAction = pFileItem->m_defaultFileExistsAction;
-					else if (pFileItem->m_defaultFileExistsAction != uploadAction)
+					}
+					else if (pFileItem->m_defaultFileExistsAction != uploadAction) {
 						upload_unknown = true;
+					}
 					has_upload = true;
 				}
 			}
@@ -2179,40 +2183,48 @@ void CQueueView::OnSetDefaultFileExistsAction(wxCommandEvent &)
 			break;
 		}
 	}
-	if (download_unknown)
+	if (download_unknown) {
 		downloadAction = CFileExistsNotification::unknown;
-	if (upload_unknown)
+	}
+	if (upload_unknown) {
 		uploadAction = CFileExistsNotification::unknown;
+	}
 
-	if (!dlg.Run(has_download ? &downloadAction : 0, has_upload ? &uploadAction : 0))
+	if (!has_upload && !has_download) {
 		return;
+	}
+
+	if (!dlg.Run(this, true, has_download ? &downloadAction : 0, has_upload ? &uploadAction : 0)) {
+		return;
+	}
 
 	item = -1;
-	for (;;)
-	{
+	for (;;) {
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-		if (item == -1)
+		if (item == -1) {
 			break;
+		}
 
 		CQueueItem* pItem = GetQueueItem(item);
-		if (!pItem)
+		if (!pItem) {
 			continue;
+		}
 
 		switch (pItem->GetType())
 		{
 		case QueueItemType::File:
 			{
 				CFileItem *pFileItem = (CFileItem*)pItem;
-				if (pFileItem->Download())
-				{
-					if (!has_download)
+				if (pFileItem->Download()) {
+					if (!has_download) {
 						break;
+					}
 					pFileItem->m_defaultFileExistsAction = downloadAction;
 				}
-				else
-				{
-					if (!has_upload)
+				else {
+					if (!has_upload) {
 						break;
+					}
 					pFileItem->m_defaultFileExistsAction = uploadAction;
 				}
 			}
@@ -2220,10 +2232,12 @@ void CQueueView::OnSetDefaultFileExistsAction(wxCommandEvent &)
 		case QueueItemType::Server:
 			{
 				CServerItem *pServerItem = (CServerItem*)pItem;
-				if (has_download)
+				if (has_download) {
 					pServerItem->SetDefaultFileExistsAction(downloadAction, TransferDirection::download);
-				if (has_upload)
+				}
+				if (has_upload) {
 					pServerItem->SetDefaultFileExistsAction(uploadAction, TransferDirection::upload);
+				}
 			}
 			break;
 		default:
@@ -2266,7 +2280,7 @@ t_EngineData* CQueueView::GetIdleEngine(Site const& site, bool allowTransient)
 
 	if (!pFirstIdle) {
 		// Check whether we can create another engine
-		const int newEngineCount = COptions::Get()->GetOptionVal(OPTION_NUMTRANSFERS);
+		const int newEngineCount = COptions::Get()->get_int(OPTION_NUMTRANSFERS);
 		if (newEngineCount > static_cast<int>(m_engineData.size()) - transient) {
 			pFirstIdle = new t_EngineData;
 			pFirstIdle->pEngine = new CFileZillaEngine(m_pMainFrame->GetEngineContext(), *this);
@@ -2708,7 +2722,7 @@ void CQueueView::ActionAfter(bool warned)
 		}
 		case ActionAfterState::RunCommand:
 		{
-			wxString cmd = COptions::Get()->GetOption(OPTION_QUEUE_COMPLETION_COMMAND);
+			wxString cmd = COptions::Get()->get_string(OPTION_QUEUE_COMPLETION_COMMAND);
 			if (!cmd.empty()) {
 				wxExecute(cmd);
 			}
@@ -2947,11 +2961,11 @@ void CQueueView::RenameFileInTransfer(CFileZillaEngine *pEngine, const wxString&
 
 std::wstring CQueueView::ReplaceInvalidCharacters(std::wstring const& filename, bool includeQuotesAndBreaks)
 {
-	if (!COptions::Get()->GetOptionVal(OPTION_INVALID_CHAR_REPLACE_ENABLE)) {
+	if (!COptions::Get()->get_int(OPTION_INVALID_CHAR_REPLACE_ENABLE)) {
 		return filename;
 	}
 
-	wchar_t const replace = COptions::Get()->GetOption(OPTION_INVALID_CHAR_REPLACE)[0];
+	wchar_t const replace = COptions::Get()->get_string(OPTION_INVALID_CHAR_REPLACE)[0];
 
 	std::wstring ret = filename;
 	for (auto & c : ret) {
@@ -3042,7 +3056,7 @@ WXLRESULT CQueueView::MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lPara
 }
 #endif
 
-void CQueueView::OnOptionsChanged(changed_options_t const&)
+void CQueueView::OnOptionsChanged(watched_options const&)
 {
 	if (m_activeMode) {
 		AdvanceQueue();
@@ -3076,7 +3090,7 @@ void CQueueView::OnStateChange(CState*, t_statechange_notifications notification
 			return;
 		}
 
-		bool const forget = COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 0;
+		bool const forget = COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 0;
 		for (auto it = m_serverList.begin(); it != m_serverList.end(); ) {
 			Site site = (*it)->GetSite();
 			if (!forget) {
@@ -3105,7 +3119,7 @@ void CQueueView::OnStateChange(CState*, t_statechange_notifications notification
 	else if (notification == STATECHANGE_QUITNOW) {
 		if (m_quit != 2) {
 			SaveQueue(false);
-			SaveColumnSettings(OPTION_QUEUE_COLUMN_WIDTHS, -1, -1);
+			SaveColumnSettings(OPTION_QUEUE_COLUMN_WIDTHS, OPTIONS_NUM, OPTIONS_NUM);
 		}
 	}
 }
