@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "commandqueue.h"
 #include "Mainfrm.h"
 #include "state.h"
@@ -136,7 +136,7 @@ void CCommandQueue::Finish(std::unique_ptr<COperationNotification> && pNotificat
 		return;
 	}
 
-	ProcessReply(pNotification->nReplyCode, pNotification->commandId);
+	ProcessReply(pNotification->replyCode_, pNotification->commandId_);
 }
 
 void CCommandQueue::ProcessReply(int nReplyCode, Command commandId)
