@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "cmdline.h"
 #include "commandqueue.h"
 #include "context_control.h"
@@ -161,29 +161,40 @@ void CContextControl::CreateContextControls(CState& state)
 #else
 	const wxPoint initial_position(wxDefaultPosition);
 #endif
-
+	wxSize paneSizes[3] = { {-1, -1}, {-1, -1}, {-1, -1}};
 	std::tuple<double, int, int> splitterPositions;
 
 	if (!m_context_controls.empty()) {
 
-		splitterPositions = m_context_controls[m_current_context_controls].GetSplitterPositions();
-		m_context_controls[m_current_context_controls].pLocalListView->SaveColumnSettings(OPTION_LOCALFILELIST_COLUMN_WIDTHS, OPTION_LOCALFILELIST_COLUMN_SHOWN, OPTION_LOCALFILELIST_COLUMN_ORDER);
-		m_context_controls[m_current_context_controls].pRemoteListView->SaveColumnSettings(OPTION_REMOTEFILELIST_COLUMN_WIDTHS, OPTION_REMOTEFILELIST_COLUMN_SHOWN, OPTION_REMOTEFILELIST_COLUMN_ORDER);
+		auto & currentControls = m_context_controls[m_current_context_controls];
+
+		if (currentControls.pViewSplitter) {
+			paneSizes[0] = currentControls.pViewSplitter->GetSize();
+		}
+		if (currentControls.pLocalSplitter) {
+			paneSizes[1] = currentControls.pLocalSplitter->GetSize();
+		}
+		if (currentControls.pRemoteSplitter) {
+			paneSizes[2] = currentControls.pRemoteSplitter->GetSize();
+		}
+
+		splitterPositions = currentControls.GetSplitterPositions();
+		currentControls.pLocalListView->SaveColumnSettings(OPTION_LOCALFILELIST_COLUMN_WIDTHS, OPTION_LOCALFILELIST_COLUMN_SHOWN, OPTION_LOCALFILELIST_COLUMN_ORDER);
+		currentControls.pRemoteListView->SaveColumnSettings(OPTION_REMOTEFILELIST_COLUMN_WIDTHS, OPTION_REMOTEFILELIST_COLUMN_SHOWN, OPTION_REMOTEFILELIST_COLUMN_ORDER);
 		
 		if (!m_tabs) {
 			m_tabs = new wxAuiNotebookEx();
 
-			wxSize splitter_size = m_context_controls[m_current_context_controls].pViewSplitter->GetSize();
-			m_tabs->Create(this, wxID_ANY, initial_position, splitter_size, wxNO_BORDER | wxAUI_NB_SCROLL_BUTTONS | wxAUI_NB_WINDOWLIST_BUTTON | wxAUI_NB_CLOSE_ON_ALL_TABS | wxAUI_NB_TAB_MOVE);
+			m_tabs->Create(this, wxID_ANY, initial_position, paneSizes[0], wxNO_BORDER | wxAUI_NB_SCROLL_BUTTONS | wxAUI_NB_WINDOWLIST_BUTTON | wxAUI_NB_CLOSE_ON_ALL_TABS | wxAUI_NB_TAB_MOVE);
 			m_tabs->SetExArtProvider();
 			m_tabs->SetSelectedFont(*wxNORMAL_FONT);
 			m_tabs->SetMeasuringFont(*wxNORMAL_FONT);
 
-			m_context_controls[m_current_context_controls].pViewSplitter->Reparent(m_tabs);
+			currentControls.pViewSplitter->Reparent(m_tabs);
 
-			m_tabs->AddPage(m_context_controls[m_current_context_controls].pViewSplitter, m_context_controls[m_current_context_controls].pState->GetTitle());
-			m_tabs->SetTabColour(0, m_context_controls[m_current_context_controls].pState->GetSite().m_colour);
-			ReplaceWindow(m_context_controls[m_current_context_controls].pViewSplitter, m_tabs);
+			m_tabs->AddPage(currentControls.pViewSplitter, currentControls.pState->GetTitle());
+			m_tabs->SetTabColour(0, currentControls.pState->GetSite().m_colour);
+			ReplaceWindow(currentControls.pViewSplitter, m_tabs);
 
 			m_tabs->Connect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGED, wxAuiNotebookEventHandler(CContextControl::OnTabChanged), 0, this);
 			m_tabs->Connect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSE, wxAuiNotebookEventHandler(CContextControl::OnTabClosing), 0, this);
@@ -203,14 +214,14 @@ void CContextControl::CreateContextControls(CState& state)
 	CContextControl::_context_controls context_controls;
 
 	context_controls.pState = &state;
-	context_controls.pViewSplitter = new CSplitterWindowEx(parent, -1, initial_position, wxDefaultSize, wxSP_NOBORDER  | wxSP_LIVE_UPDATE);
+	context_controls.pViewSplitter = new CSplitterWindowEx(parent, -1, initial_position, paneSizes[0], wxSP_NOBORDER  | wxSP_LIVE_UPDATE);
 	context_controls.pViewSplitter->SetMinimumPaneSize(50, 100);
 	context_controls.pViewSplitter->SetSashGravity(0.5);
 
-	context_controls.pLocalSplitter = new CSplitterWindowEx(context_controls.pViewSplitter, -1, wxDefaultPosition, wxDefaultSize, wxSP_NOBORDER  | wxSP_LIVE_UPDATE);
+	context_controls.pLocalSplitter = new CSplitterWindowEx(context_controls.pViewSplitter, -1, wxDefaultPosition, paneSizes[1], wxSP_NOBORDER  | wxSP_LIVE_UPDATE);
 	context_controls.pLocalSplitter->SetMinimumPaneSize(50, 100);
 
-	context_controls.pRemoteSplitter = new CSplitterWindowEx(context_controls.pViewSplitter, -1, wxDefaultPosition, wxDefaultSize, wxSP_NOBORDER  | wxSP_LIVE_UPDATE);
+	context_controls.pRemoteSplitter = new CSplitterWindowEx(context_controls.pViewSplitter, -1, wxDefaultPosition, paneSizes[2], wxSP_NOBORDER  | wxSP_LIVE_UPDATE);
 	context_controls.pRemoteSplitter->SetMinimumPaneSize(50, 100);
 
 	context_controls.pLocalTreeViewPanel = new CView(context_controls.pLocalSplitter);
@@ -227,7 +238,7 @@ void CContextControl::CreateContextControls(CState& state)
 	context_controls.pRemoteTreeViewPanel->SetWindow(context_controls.pRemoteTreeView);
 	context_controls.pRemoteListViewPanel->SetWindow(context_controls.pRemoteListView);
 
-	bool show_filelist_statusbars = COptions::Get()->GetOptionVal(OPTION_FILELIST_STATUSBAR) != 0;
+	bool show_filelist_statusbars = COptions::Get()->get_int(OPTION_FILELIST_STATUSBAR) != 0;
 
 	CFilelistStatusBar* pLocalFilelistStatusBar = new CFilelistStatusBar(context_controls.pLocalListViewPanel);
 	if (!show_filelist_statusbars) {
@@ -260,8 +271,8 @@ void CContextControl::CreateContextControls(CState& state)
 	context_controls.pRemoteListSearchPanel = new CListSearchPanel(context_controls.pRemoteListViewPanel, context_controls.pRemoteListView, context_controls.pState, false);
 	context_controls.pRemoteListViewPanel->SetSearchPanel(context_controls.pRemoteListSearchPanel);
 
-	const int layout = COptions::Get()->GetOptionVal(OPTION_FILEPANE_LAYOUT);
-	const int swap = COptions::Get()->GetOptionVal(OPTION_FILEPANE_SWAP);
+	const int layout = COptions::Get()->get_int(OPTION_FILEPANE_LAYOUT);
+	const int swap = COptions::Get()->get_int(OPTION_FILEPANE_SWAP);
 
 	if (layout == 1) {
 		if (swap) {
@@ -280,7 +291,7 @@ void CContextControl::CreateContextControls(CState& state)
 		}
 	}
 
-	if (COptions::Get()->GetOptionVal(OPTION_SHOW_TREE_LOCAL)) {
+	if (COptions::Get()->get_int(OPTION_SHOW_TREE_LOCAL)) {
 		context_controls.pLocalViewHeader = new CLocalViewHeader(context_controls.pLocalTreeViewPanel, state);
 		context_controls.pLocalTreeViewPanel->SetHeader(context_controls.pLocalViewHeader);
 		if (layout == 3 && swap) {
@@ -300,7 +311,7 @@ void CContextControl::CreateContextControls(CState& state)
 		context_controls.pLocalSplitter->Initialize(context_controls.pLocalListViewPanel);
 	}
 
-	if (COptions::Get()->GetOptionVal(OPTION_SHOW_TREE_REMOTE)) {
+	if (COptions::Get()->get_int(OPTION_SHOW_TREE_REMOTE)) {
 		context_controls.pRemoteViewHeader = new CRemoteViewHeader(context_controls.pRemoteTreeViewPanel, state);
 		context_controls.pRemoteTreeViewPanel->SetHeader(context_controls.pRemoteViewHeader);
 		if (layout == 3 && !swap) {
@@ -688,7 +699,7 @@ void CContextControl::SaveTabs()
 		}
 	}
 
-	COptions::Get()->SetOptionXml(OPTION_TAB_DATA, xml);
+	COptions::Get()->set(OPTION_TAB_DATA, xml);
 }
 
 void CContextControl::RestoreTabs()
@@ -699,9 +710,9 @@ void CContextControl::RestoreTabs()
 
 	int selected = 0;
 
-	auto xml = COptions::Get()->GetOptionXml(OPTION_TAB_DATA);
+	auto xml = COptions::Get()->get_xml(OPTION_TAB_DATA);
 
-	bool selectedOnly = COptions::Get()->GetOptionVal(OPTION_STARTUP_ACTION) != 2;
+	bool selectedOnly = COptions::Get()->get_int(OPTION_STARTUP_ACTION) != 2;
 
 	CCommandLine const* pCommandLine = wxGetApp().GetCommandLine();
 	if (pCommandLine && pCommandLine->BlocksReconnectAtStartup()) {
